@@ -285,6 +285,10 @@ class Task(object, metaclass=MetaTask):
             return None
         return self._data_without_value.path
 
+    def reset_data(self):
+        self._data = None
+        return self
+
     def force(self, delete_data=False):
         """
         Switch task to forced state to allow data recomputation.
@@ -331,6 +335,7 @@ class Task(object, metaclass=MetaTask):
             self._data = run_result
             self._init_persistence(self._data)
         elif isinstance(run_result, self.data_type) or custom_isinstance(run_result, self.data_type) or fullname(self.data_type) == 'typing.Generator':
+            assert self._data is not None, f'{fullname(self.__class__)}: attribute "_data" cannot be None'
             self._data.set_value(run_result)
         else:
             raise ValueError(f'{fullname(self.__class__)}: Invalid result data type: {type(run_result)} instead of {self.data_type}')
