@@ -177,9 +177,9 @@ def get_classes_by_import_string(string: str, cls: Type[object] = object):
     if type(members) is not list:
         members = [members]
     classes = []
-    for members in members:
-        if inspect.isclass(members) and issubclass(members, cls):
-            classes.append(members)
+    for member in members:
+        if inspect.isclass(member) and issubclass(member, cls):
+            classes.append(member)
     return classes
 
 
@@ -231,7 +231,7 @@ def object_to_definition(obj):
         else:
             raise AttributeError(f'Value of __init__ argument `{name}` not found for class `{fullname(obj.__class__)}`, '
                                  f'make sure that value is saved in `self.{name}` or `self._{name}`')
-        if all(not isinstance(value, type_) for type_ in {int, float, bool, str, list, set, dict}):
+        if value is not None and all(not isinstance(value, type_) for type_ in {int, float, bool, str, list, set, dict}):
             value = object_to_definition(value)
         kwargs[name] = value
     return result
